@@ -7,6 +7,8 @@ from .kmerf import KMERF
 from .max_margin import MaxMargin
 from .mgc import MGC
 from .rv import RV
+from .friedman_rafsky import FriedmanRafsky
+
 
 __all__ = [s for s in dir()]  # add imported tests to __all__
 
@@ -20,4 +22,5 @@ INDEP_TESTS = {
     "mgc": MGC,
     "kmerf": KMERF,
     "maxmargin": MaxMargin,
+    "friedman_rafsky": FriedmanRafsky,
 }
