@@ -6,6 +6,9 @@ from .ksamp import KSample
 from .manova import MANOVA
 from .mmd import MMD
 
+from .smoothCF import SmoothCFTest, smooth_cf_distance
+from .mean_embedding import MeanEmbeddingTest, mean_embed_distance
+
 __all__ = [s for s in dir()]  # add imported tests to __all__
 
 
@@ -16,4 +19,6 @@ KSAMP_TESTS = {
     "ksample": KSample,
     "manova": MANOVA,
     "mmd": MMD,
+    "smoothCF": SmoothCFTest,
+    "mean_embedding": MeanEmbeddingTest,
 }
