@@ -217,7 +217,7 @@ class KSample(KSampleTest):
 
         Parameters
         ----------
-        *args : ndarray
+        *args : ndarray of float
             Variable length input data matrices. All inputs must have the same
             number of dimensions. That is, the shapes must be `(n, p)` and
             `(m, p)`, ... where `n`, `m`, ... are the number of samples and `p` is
@@ -242,7 +242,7 @@ class KSample(KSampleTest):
 
         Parameters
         ----------
-        *args : ndarray
+        *args : ndarray of float
             Variable length input data matrices. All inputs must have the same
             number of dimensions. That is, the shapes must be `(n, p)` and
             `(m, p)`, ... where `n`, `m`, ... are the number of samples and `p` is
