@@ -16,6 +16,7 @@ from ...independence import Dcorr
 from ..common import (
     _check_distmat,
     _check_kernmat,
+    _multi_check_kernmat,
     _PermTree,
     check_ndarray_xy,
     check_perm_blocks,
@@ -27,6 +28,8 @@ from ..common import (
     contains_nan,
     convert_xy_float64,
     perm_test,
+    multi_compute_kern,
+    multi_perm_test,
 )
 from ..indep_sim import linear
 
@@ -141,6 +144,12 @@ class TestErrorWarn:
         assert_raises(ValueError, _check_distmat, x, y)
         assert_raises(ValueError, _check_kernmat, x, y)
 
+    def test_error_multidistkern(self):
+        # raises error if samples are low (< 3)
+        x = np.arange(10).reshape(-1, 1)
+        y = np.arange(10).reshape(1, -1)
+        assert_raises(ValueError, _multi_check_kernmat, x, y)
+
     def test_error_nans(self):
         # raises error if inputs contain NaNs
         x = np.arange(20, dtype=float)
@@ -176,7 +185,7 @@ class TestHelper:
                 l1, (n - 1, n + 1), (l1.itemsize * (n + 1), l1.itemsize)
             )[:, 1:]
         )
-        gamma = 1.0 / (2 * (med ** 2))
+        gamma = 1.0 / (2 * (med**2))
 
         kernx = pairwise_kernels(x, x, metric="rbf", gamma=gamma)
         kerny = pairwise_kernels(y, y, metric="rbf", gamma=gamma)
@@ -208,6 +217,51 @@ class TestHelper:
         assert_array_equal(kernx, kernx_comp)
         assert_array_equal(kerny, kerny_comp)
 
+    def test_multidiskern(self):
+        np.random.seed(123456789)
+        x, y = linear(100, 1)
+        distx = pairwise_distances(x, x)
+        disty = pairwise_distances(y, y)
+
+        l1 = pairwise_distances(x, metric="l1")
+        n = l1.shape[0]
+        med = np.median(
+            np.lib.stride_tricks.as_strided(
+                l1, (n - 1, n + 1), (l1.itemsize * (n + 1), l1.itemsize)
+            )[:, 1:]
+        )
+        gamma = 1.0 / (2 * (med**2))
+
+        kernx = pairwise_kernels(x, x, metric="rbf", gamma=gamma)
+        kerny = pairwise_kernels(y, y, metric="rbf", gamma=gamma)
+
+        distx, disty = compute_dist(distx, disty, metric=None)
+        kernx, kerny = multi_compute_kern(*(kernx, kerny), metric=None)
+        distx_comp, disty_comp = compute_dist(x, y)
+        kernx_comp, kerny_comp = multi_compute_kern(*(x, y))
+        kernx_comp1, kerny_comp1 = multi_compute_kern(*(x, y), metric="rbf")
+
+        assert_array_equal(distx, distx_comp)
+        assert_array_equal(disty, disty_comp)
+        assert_array_equal(kernx, kernx_comp)
+        assert_array_equal(kerny, kerny_comp)
+        assert_array_equal(kernx, kerny_comp1)
+        assert_array_equal(kerny, kerny_comp1)
+
+        def gaussian(x, **kwargs):
+            return pairwise_kernels(x, x, metric="rbf", **kwargs)
+
+        def euclidean(x, **kwargs):
+            return pairwise_distances(x, x, metric="euclidean", **kwargs)
+
+        distx, disty = compute_dist(x, y, metric=euclidean)
+        kernx, kerny = multi_compute_kern(*(x, y), metric=gaussian, gamma=gamma)
+
+        assert_array_equal(distx, distx_comp)
+        assert_array_equal(disty, disty_comp)
+        assert_array_equal(kernx, kernx_comp)
+        assert_array_equal(kerny, kerny_comp)
+
     def test_permtest(self):
         x, y = linear(100, 1)
 
@@ -221,6 +275,13 @@ class TestHelper:
         assert_almost_equal(stat, 1.0, decimal=1)
         assert_almost_equal(pvalue, 1 / 1000, decimal=1)
 
+    def test_multipermtest(self):
+        x, y = linear(100, 1)
+
+        stat, pvalue, _ = multi_perm_test(Dcorr().statistic, *(x, y))
+        assert_almost_equal(stat, 1.0, decimal=1)
+        assert_almost_equal(pvalue, 1 / 1000, decimal=1)
+
     def test_chi2(self):
         x, y = linear(100, 1)
 
